@@ -1,5 +1,5 @@
 package App::pherkin;
-$App::pherkin::VERSION = '0.75';
+$App::pherkin::VERSION = '0.83';
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ use Module::Runtime qw(use_module module_notional_filename);
 use List::Util qw(max);
 use Pod::Usage;
 use FindBin qw($RealBin $Script);
-use YAML::Syck;
+use YAML qw( LoadFile );
 use Data::Dumper;
 use File::Spec;
 use Path::Class qw/file dir/;
@@ -36,7 +36,7 @@ App::pherkin - Run Cucumber tests from the command line
 
 =head1 VERSION
 
-version 0.75
+version 0.83
 
 =head1 SYNOPSIS
 
@@ -145,6 +145,9 @@ sub _run_tests {
 sub _initialize_harness {
     my ( $self, $harness_module ) = @_;
 
+    my $harness_args_string = undef;
+    ( $harness_module, $harness_args_string ) = split /\(/, $harness_module, 2; 
+    
     unless ( $harness_module =~ m/::/ ) {
         $harness_module = "Test::BDD::Cucumber::Harness::" . $harness_module;
     }
@@ -152,7 +155,15 @@ sub _initialize_harness {
     eval { use_module($harness_module) }
         || die "Unable to load harness [$harness_module]: $@";
 
-    $self->harness( $harness_module->new() );
+    if ( $harness_args_string ) {
+        my %harness_args;
+        eval "%harness_args = ($harness_args_string; 1"
+           or die $@;
+        $self->harness( $harness_module->new( %harness_args ) );
+    } else {
+        $self->harness( $harness_module->new() );
+    }
+    
 }
 
 sub _find_config_file {
@@ -184,6 +195,40 @@ sub _find_config_file {
     return undef;
 }
 
+sub _replace_helper {
+    my $inval = shift;
+
+    return $ENV{$inval} // "Environment variable $inval not defined";
+}
+
+sub _resolve_envvars {
+    my ( $config_data ) = shift;
+
+    if (ref $config_data) {
+        if (ref $config_data eq 'HASH') {
+            return {
+                map {
+                    $_ => _resolve_envvars( $config_data->{$_} )
+                } keys %$config_data
+            };
+        }
+        elsif (ref $config_data eq 'ARRAY') {
+            return [ map { _resolve_envvars( $_ ) } @$config_data ];
+        }
+        else {
+            die 'Unhandled reference type in configuration data';
+        }
+    }
+    else {
+        # replace (in-place) ${ENVVAR_NAME} sequences with the envvar value
+        $config_data =~ s/(?<!\$)\$\{([a-zA-Z0-9_]+)\}/_replace_helper($1)/ge;
+        # remove any escaping double dollar-signs
+        $config_data =~ s/\$(\$\{[a-zA-Z0-9_]+\})/$1/g;
+    }
+
+    return $config_data;
+}
+
 sub _load_config {
     my ( $self, $profile_name, $proposed_config_filename, $debug ) = @_;
 
@@ -195,6 +240,8 @@ sub _load_config {
     if ($config_filename) {
         print "Found [$config_filename], reading...\n" if $debug;
         $config_data_whole = LoadFile($config_filename);
+        $config_data_whole = _resolve_envvars( $config_data_whole )
+            if $config_data_whole;
     } else {
         if ($profile_name) {
             print "No configuration files found\n" if $debug;
@@ -274,6 +321,7 @@ sub _process_arguments {
 
         # Standard
         help       => [ 'h|help|?' ],
+        version    => [ 'version' ],
         includes   => [ 'I=s@', [] ],
         lib        => [ 'l|lib' ],
         blib       => [ 'b|blib' ],
@@ -301,6 +349,14 @@ sub _process_arguments {
         return ( ref $value eq 'ARRAY' ) ? $value : $$value;
     };
 
+    if ( $deref->('version') ) {
+        my ($vol, $dirs, $file) = File::Spec->splitpath( $0 );
+        my $version = $App::pherkin::VERSION || '(development)';
+        print "$file $version\n";
+
+        exit 0;
+    }
+
     pod2usage(
         -verbose => 1,
         -input   => "$RealBin/$Script",
@@ -568,7 +624,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-  Copyright 2019-2020, Erik Huelsmann
+  Copyright 2019-2021, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
